==> apache-inlong-0.10.0-incubating-src.tar.gz: apache-inlong-0.10.0-incubating/inlong-manager/manager-dao/src/main/java/org/apache/inlong/manager/dao/entity/ConsumptionEntity.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.manager.dao.entity;

import java.io.Serializable;
import java.util.Date;
import lombok.Data;

/**
 * Data consumption table
 */
@Data
public class ConsumptionEntity implements Serializable {

    private static final long serialVersionUID = 1L;
    private Integer id;
    private String consumerGroupName;
    private String consumerGroupId;
    private String inCharges;
    private String businessIdentifier;
    private String middlewareType;
    private String topic;
    private Integer filterEnabled;
    private String dataStreamIdentifier;
    private Integer status;
    private String creator;
    private String modifier;
    private Date createTime;
    private Date modifyTime;
    private Integer isDeleted;

}

==> apache-inlong-1.0.0-incubating-src.tar.gz: apache-inlong-1.0.0-incubating/inlong-manager/manager-dao/src/main/java/org/apache/inlong/manager/dao/entity/ConsumptionEntity.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.manager.dao.entity;

import java.io.Serializable;
import java.util.Date;
import lombok.Data;

/**
 * Data consumption table
 */
@Data
public class ConsumptionEntity implements Serializable {

    private static final long serialVersionUID = 1L;
    private Integer id;
    private String consumerGroupName;
    private String consumerGroupId;
    private String inCharges;
    private String inlongGroupId;
    private String middlewareType;
    private String topic;
    private Integer filterEnabled;
    private String inlongStreamId;
    private Integer status;
    private String creator;
    private String modifier;
    private Date createTime;
    private Date modifyTime;
    private Integer isDeleted;

}
